@@ -13,14 +13,8 @@
 #include <QFile>
 #include <QProcess>
 
-#include <kauth_version.h>
-#if KAUTH_VERSION >= QT_VERSION_CHECK(5, 92, 0)
 #include <KAuth/Action>
 #include <KAuth/ExecuteJob>
-#else
-#include <KAuthAction>
-#include <KAuthExecuteJob>
-#endif
 
 #include <KConfigGroup>
 #include <KLocalizedString>
@@ -68,7 +62,7 @@ int main(int argc, char **argv)
         if (!rc) {
             QString errorString = job->errorString();
             if (!errorString.isEmpty()) {
-                KMessageBox::sorry(nullptr, errorString, i18n("Unable to install theme"));
+                KMessageBox::error(nullptr, errorString, i18n("Unable to install theme"));
             }
             return -1;
         }
